@@ -1,7 +1,3 @@
-import logging
-
-from importlib import import_module
-
 from alira.instance import Instance
 from alira.modules.module import Module
 
