@@ -38,7 +38,7 @@ class Module(object):
             logging.info(f"Loaded function {function_name}")
 
             return function
-        except Exception as e:
+        except Exception:
             logging.exception(f"Unable to load function {function_name}")
             return None
 
